@@ -48,10 +48,6 @@ import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
 import org.apache.tomcat.util.res.StringManager;
 
-
-/**
- * @author Amy Roh
- */
 public class MBeanFactory {
 
     private static final Log log = LogFactory.getLog(MBeanFactory.class);
@@ -76,6 +72,7 @@ public class MBeanFactory {
 
     /**
      * Set the container that this factory was created for.
+     *
      * @param container The associated container
      */
     public void setContainer(Object container) {
@@ -84,10 +81,10 @@ public class MBeanFactory {
 
 
     /**
-     * Little convenience method to remove redundant code
-     * when retrieving the path string
+     * Little convenience method to remove redundant code when retrieving the path string
      *
      * @param t path string
+     *
      * @return empty string if t==null || t.equals("/")
      */
     private String getPathStr(String t) {
@@ -97,34 +94,30 @@ public class MBeanFactory {
         return t;
     }
 
-   /**
-     * Get Parent Container to add its child component
-     * from parent's ObjectName
+    /**
+     * Get Parent Container to add its child component from parent's ObjectName
      */
-    private Container getParentContainerFromParent(ObjectName pname)
-        throws Exception {
+    private Container getParentContainerFromParent(ObjectName pname) throws Exception {
 
         String type = pname.getKeyProperty("type");
         String j2eeType = pname.getKeyProperty("j2eeType");
         Service service = getService(pname);
         StandardEngine engine = (StandardEngine) service.getContainer();
-        if ((j2eeType!=null) && (j2eeType.equals("WebModule"))) {
+        if ((j2eeType != null) && (j2eeType.equals("WebModule"))) {
             String name = pname.getKeyProperty("name");
             name = name.substring(2);
             int i = name.indexOf('/');
-            String hostName = name.substring(0,i);
+            String hostName = name.substring(0, i);
             String path = name.substring(i);
             Container host = engine.findChild(hostName);
             String pathStr = getPathStr(path);
-            Container context = host.findChild(pathStr);
-            return context;
+            return host.findChild(pathStr);
         } else if (type != null) {
             if (type.equals("Engine")) {
                 return engine;
             } else if (type.equals("Host")) {
                 String hostName = pname.getKeyProperty("host");
-                Container host = engine.findChild(hostName);
-                return host;
+                return engine.findChild(hostName);
             }
         }
         return null;
@@ -133,11 +126,9 @@ public class MBeanFactory {
 
 
     /**
-     * Get Parent ContainerBase to add its child component
-     * from child component's ObjectName  as a String
+     * Get Parent ContainerBase to add its child component from child component's ObjectName as a String
      */
-    private Container getParentContainerFromChild(ObjectName oname)
-        throws Exception {
+    private Container getParentContainerFromChild(ObjectName oname) throws Exception {
 
         String hostName = oname.getKeyProperty("host");
         String path = oname.getKeyProperty("path");
@@ -148,14 +139,12 @@ public class MBeanFactory {
             return engine;
         } else if (path == null) {
             // child's container is Host
-            Container host = engine.findChild(hostName);
-            return host;
+            return engine.findChild(hostName);
         } else {
             // child's container is Context
             Container host = engine.findChild(hostName);
             path = getPathStr(path);
-            Container context = host.findChild(path);
-            return context;
+            return host.findChild(path);
         }
     }
 
@@ -170,7 +159,7 @@ public class MBeanFactory {
         StandardService service = null;
         String domain = oname.getDomain();
         if (container instanceof Server) {
-            Service[] services = ((Server)container).findServices();
+            Service[] services = ((Server) container).findServices();
             for (Service value : services) {
                 service = (StandardService) value;
                 if (domain.equals(service.getObjectName().getDomain())) {
@@ -178,8 +167,7 @@ public class MBeanFactory {
                 }
             }
         }
-        if (service == null ||
-                !service.getObjectName().getDomain().equals(domain)) {
+        if (service == null || !service.getObjectName().getDomain().equals(domain)) {
             throw new Exception(sm.getString("mBeanFactory.noService", domain));
         }
         return service;
@@ -190,15 +178,15 @@ public class MBeanFactory {
     /**
      * Create a new AjpConnector
      *
-     * @param parent MBean Name of the associated parent component
+     * @param parent  MBean Name of the associated parent component
      * @param address The IP address on which to bind
-     * @param port TCP port number to listen on
+     * @param port    TCP port number to listen on
+     *
      * @return the object name of the created connector
      *
      * @exception Exception if an MBean cannot be created or registered
      */
-    public String createAjpConnector(String parent, String address, int port)
-        throws Exception {
+    public String createAjpConnector(String parent, String address, int port) throws Exception {
 
         return createConnector(parent, address, port, true, false);
     }
@@ -207,19 +195,20 @@ public class MBeanFactory {
     /**
      * Create a new DataSource Realm.
      *
-     * @param parent MBean Name of the associated parent component
+     * @param parent         MBean Name of the associated parent component
      * @param dataSourceName the datasource name
-     * @param roleNameCol the column name for the role names
-     * @param userCredCol the column name for the user credentials
-     * @param userNameCol the column name for the user names
-     * @param userRoleTable the table name for the roles table
-     * @param userTable the table name for the users
+     * @param roleNameCol    the column name for the role names
+     * @param userCredCol    the column name for the user credentials
+     * @param userNameCol    the column name for the usernames
+     * @param userRoleTable  the table name for the roles table
+     * @param userTable      the table name for the users
+     *
      * @return the object name of the created realm
+     *
      * @exception Exception if an MBean cannot be created or registered
      */
-    public String createDataSourceRealm(String parent, String dataSourceName,
-        String roleNameCol, String userCredCol, String userNameCol,
-        String userRoleTable, String userTable) throws Exception {
+    public String createDataSourceRealm(String parent, String dataSourceName, String roleNameCol, String userCredCol,
+            String userNameCol, String userRoleTable, String userTable) throws Exception {
 
         // Create a new DataSourceRealm instance
         DataSourceRealm realm = new DataSourceRealm();
@@ -238,6 +227,9 @@ public class MBeanFactory {
     private String addRealmToParent(String parent, Realm realm) throws Exception {
         ObjectName pname = new ObjectName(parent);
         Container container = getParentContainerFromParent(pname);
+        if (container == null) {
+            throw new IllegalArgumentException(sm.getString("mBeanFactory.noParent", parent));
+        }
         // Add the new instance to its parent component
         container.setRealm(realm);
         // Return the corresponding MBean name
@@ -256,15 +248,15 @@ public class MBeanFactory {
     /**
      * Create a new HttpConnector
      *
-     * @param parent MBean Name of the associated parent component
+     * @param parent  MBean Name of the associated parent component
      * @param address The IP address on which to bind
-     * @param port TCP port number to listen on
+     * @param port    TCP port number to listen on
+     *
      * @return the object name of the created connector
      *
      * @exception Exception if an MBean cannot be created or registered
      */
-    public String createHttpConnector(String parent, String address, int port)
-            throws Exception {
+    public String createHttpConnector(String parent, String address, int port) throws Exception {
         return createConnector(parent, address, port, false, false);
     }
 
@@ -272,20 +264,20 @@ public class MBeanFactory {
     /**
      * Create a new Connector
      *
-     * @param parent MBean Name of the associated parent component
+     * @param parent  MBean Name of the associated parent component
      * @param address The IP address on which to bind
-     * @param port TCP port number to listen on
-     * @param isAjp Create a AJP/1.3 Connector
-     * @param isSSL Create a secure Connector
+     * @param port    TCP port number to listen on
+     * @param isAjp   Create a AJP/1.3 Connector
+     * @param isSSL   Create a secure Connector
      *
      * @exception Exception if an MBean cannot be created or registered
      */
     private String createConnector(String parent, String address, int port, boolean isAjp, boolean isSSL)
-        throws Exception {
+            throws Exception {
         // Set the protocol in the constructor
         String protocol = isAjp ? "AJP/1.3" : "HTTP/1.1";
         Connector retobj = new Connector(protocol);
-        if ((address!=null) && (address.length()>0)) {
+        if ((address != null) && (!address.isEmpty())) {
             retobj.setProperty("address", address);
         }
         // Set port number
@@ -309,15 +301,15 @@ public class MBeanFactory {
     /**
      * Create a new HttpsConnector
      *
-     * @param parent MBean Name of the associated parent component
+     * @param parent  MBean Name of the associated parent component
      * @param address The IP address on which to bind
-     * @param port TCP port number to listen on
+     * @param port    TCP port number to listen on
+     *
      * @return the object name of the created connector
      *
      * @exception Exception if an MBean cannot be created or registered
      */
-    public String createHttpsConnector(String parent, String address, int port)
-        throws Exception {
+    public String createHttpsConnector(String parent, String address, int port) throws Exception {
         return createConnector(parent, address, port, false, true);
     }
 
@@ -325,22 +317,21 @@ public class MBeanFactory {
     /**
      * Create a new JDBC Realm.
      *
-     * @param parent MBean Name of the associated parent component
-     * @param driverName JDBC driver name
-     * @param connectionName the user name for the connection
+     * @param parent             MBean Name of the associated parent component
+     * @param driverName         JDBC driver name
+     * @param connectionName     the user name for the connection
      * @param connectionPassword the password for the connection
-     * @param connectionURL the connection URL to the database
+     * @param connectionURL      the connection URL to the database
+     *
      * @return the object name of the created realm
      *
      * @exception Exception if an MBean cannot be created or registered
      *
-     * @deprecated This method will be removed in Tomcat 10. Use a
-     *             DataSourceRealm instead.
+     * @deprecated This method will be removed in Tomcat 10. Use a DataSourceRealm instead.
      */
     @Deprecated
-    public String createJDBCRealm(String parent, String driverName,
-        String connectionName, String connectionPassword, String connectionURL)
-        throws Exception {
+    public String createJDBCRealm(String parent, String driverName, String connectionName, String connectionPassword,
+            String connectionURL) throws Exception {
 
         // Create a new JDBCRealm instance
         org.apache.catalina.realm.JDBCRealm realm = new org.apache.catalina.realm.JDBCRealm();
@@ -358,13 +349,14 @@ public class MBeanFactory {
      * Create a new JNDI Realm.
      *
      * @param parent MBean Name of the associated parent component
+     *
      * @return the object name of the created realm
      *
      * @exception Exception if an MBean cannot be created or registered
      */
     public String createJNDIRealm(String parent) throws Exception {
 
-         // Create a new JNDIRealm instance
+        // Create a new JNDIRealm instance
         JNDIRealm realm = new JNDIRealm();
 
         // Add the new instance to its parent component
@@ -376,13 +368,14 @@ public class MBeanFactory {
      * Create a new Memory Realm.
      *
      * @param parent MBean Name of the associated parent component
+     *
      * @return the object name of the created realm
      *
      * @exception Exception if an MBean cannot be created or registered
      */
     public String createMemoryRealm(String parent) throws Exception {
 
-         // Create a new MemoryRealm instance
+        // Create a new MemoryRealm instance
         MemoryRealm realm = new MemoryRealm();
 
         // Add the new instance to its parent component
@@ -390,20 +383,18 @@ public class MBeanFactory {
     }
 
 
-   /**
+    /**
      * Create a new StandardContext.
      *
-     * @param parent MBean Name of the associated parent component
-     * @param path The context path for this Context
+     * @param parent  MBean Name of the associated parent component
+     * @param path    The context path for this Context
      * @param docBase Document base directory (or WAR) for this Context
+     *
      * @return the object name of the created context
      *
      * @exception Exception if an MBean cannot be created or registered
      */
-    public String createStandardContext(String parent,
-                                        String path,
-                                        String docBase)
-        throws Exception {
+    public String createStandardContext(String parent, String path, String docBase) throws Exception {
 
         return createStandardContext(parent, path, docBase, false, false);
     }
@@ -412,21 +403,18 @@ public class MBeanFactory {
     /**
      * Create a new StandardContext.
      *
-     * @param parent MBean Name of the associated parent component
-     * @param path The context path for this Context
-     * @param docBase Document base directory (or WAR) for this Context
-     * @param xmlValidation if XML descriptors should be validated
+     * @param parent            MBean Name of the associated parent component
+     * @param path              The context path for this Context
+     * @param docBase           Document base directory (or WAR) for this Context
+     * @param xmlValidation     if XML descriptors should be validated
      * @param xmlNamespaceAware if the XML processor should namespace aware
+     *
      * @return the object name of the created context
      *
      * @exception Exception if an MBean cannot be created or registered
      */
-    public String createStandardContext(String parent,
-                                        String path,
-                                        String docBase,
-                                        boolean xmlValidation,
-                                        boolean xmlNamespaceAware)
-        throws Exception {
+    public String createStandardContext(String parent, String path, String docBase, boolean xmlValidation,
+            boolean xmlNamespaceAware) throws Exception {
 
         // Create a new StandardContext instance
         StandardContext context = new StandardContext();
@@ -441,32 +429,28 @@ public class MBeanFactory {
 
         // Add the new instance to its parent component
         ObjectName pname = new ObjectName(parent);
-        ObjectName deployer = new ObjectName(pname.getDomain()+
-                                             ":type=Deployer,host="+
-                                             pname.getKeyProperty("host"));
-        if(mserver.isRegistered(deployer)) {
+        ObjectName deployer = new ObjectName(pname.getDomain() + ":type=Deployer,host=" + pname.getKeyProperty("host"));
+        if (mserver.isRegistered(deployer)) {
             String contextName = context.getName();
-            Boolean result = (Boolean) mserver.invoke(deployer, "tryAddServiced",
-                    new Object [] {contextName},
-                    new String [] {"java.lang.String"});
+            Boolean result = (Boolean) mserver.invoke(deployer, "tryAddServiced", new Object[] { contextName },
+                    new String[] { "java.lang.String" });
             if (result.booleanValue()) {
                 try {
-                    String configPath = (String)mserver.getAttribute(deployer, "configBaseName");
+                    String configPath = (String) mserver.getAttribute(deployer, "configBaseName");
                     String baseName = context.getBaseName();
-                    File configFile = new File(new File(configPath), baseName+".xml");
+                    File configFile = new File(new File(configPath), baseName + ".xml");
                     if (configFile.isFile()) {
                         context.setConfigFile(configFile.toURI().toURL());
                     }
-                    mserver.invoke(deployer, "manageApp",
-                            new Object[] {context},
-                            new String[] {"org.apache.catalina.Context"});
+                    mserver.invoke(deployer, "manageApp", new Object[] { context },
+                            new String[] { "org.apache.catalina.Context" });
                 } finally {
-                    mserver.invoke(deployer, "removeServiced",
-                            new Object [] {contextName},
-                            new String [] {"java.lang.String"});
+                    mserver.invoke(deployer, "removeServiced", new Object[] { contextName },
+                            new String[] { "java.lang.String" });
                 }
             } else {
-                throw new IllegalStateException(sm.getString("mBeanFactory.contextCreate.addServicedFail", contextName));
+                throw new IllegalStateException(
+                        sm.getString("mBeanFactory.contextCreate.addServicedFail", contextName));
             }
         } else {
             log.warn(sm.getString("mBeanFactory.noDeployer", pname.getKeyProperty("host")));
@@ -484,24 +468,20 @@ public class MBeanFactory {
     /**
      * Create a new StandardHost.
      *
-     * @param parent MBean Name of the associated parent component
-     * @param name Unique name of this Host
-     * @param appBase Application base directory name
-     * @param autoDeploy Should we auto deploy?
+     * @param parent          MBean Name of the associated parent component
+     * @param name            Unique name of this Host
+     * @param appBase         Application base directory name
+     * @param autoDeploy      Should we auto deploy?
      * @param deployOnStartup Deploy on server startup?
-     * @param deployXML Should we deploy Context XML config files property?
-     * @param unpackWARs Should we unpack WARs when auto deploying?
+     * @param deployXML       Should we deploy Context XML config files property?
+     * @param unpackWARs      Should we unpack WARs when auto deploying?
+     *
      * @return the object name of the created host
      *
      * @exception Exception if an MBean cannot be created or registered
      */
-    public String createStandardHost(String parent, String name,
-                                     String appBase,
-                                     boolean autoDeploy,
-                                     boolean deployOnStartup,
-                                     boolean deployXML,
-                                     boolean unpackWARs)
-        throws Exception {
+    public String createStandardHost(String parent, String name, String appBase, boolean autoDeploy,
+            boolean deployOnStartup, boolean deployXML, boolean unpackWARs) throws Exception {
 
         // Create a new StandardHost instance
         StandardHost host = new StandardHost();
@@ -531,15 +511,15 @@ public class MBeanFactory {
     /**
      * Creates a new StandardService and StandardEngine.
      *
-     * @param domain       Domain name for the container instance
-     * @param defaultHost  Name of the default host to be used in the Engine
-     * @param baseDir      Base directory value for Engine
+     * @param domain      Domain name for the container instance
+     * @param defaultHost Name of the default host to be used in the Engine
+     * @param baseDir     Base directory value for Engine
+     *
      * @return the object name of the created service
      *
      * @exception Exception if an MBean cannot be created or registered
      */
-    public String createStandardServiceEngine(String domain,
-            String defaultHost, String baseDir) throws Exception{
+    public String createStandardServiceEngine(String domain, String defaultHost, String baseDir) throws Exception {
 
         if (!(container instanceof Server)) {
             throw new Exception(sm.getString("mBeanFactory.notServer"));
@@ -564,12 +544,12 @@ public class MBeanFactory {
      * Create a new StandardManager.
      *
      * @param parent MBean Name of the associated parent component
+     *
      * @return the object name of the created manager
      *
      * @exception Exception if an MBean cannot be created or registered
      */
-    public String createStandardManager(String parent)
-        throws Exception {
+    public String createStandardManager(String parent) throws Exception {
 
         // Create a new StandardManager instance
         StandardManager manager = new StandardManager();
@@ -593,19 +573,18 @@ public class MBeanFactory {
 
 
     /**
-     * Create a new  UserDatabaseRealm.
+     * Create a new UserDatabaseRealm.
+     *
+     * @param parent       MBean Name of the associated parent component
+     * @param resourceName Global JNDI resource name of the associated UserDatabase
      *
-     * @param parent MBean Name of the associated parent component
-     * @param resourceName Global JNDI resource name of the associated
-     *  UserDatabase
      * @return the object name of the created realm
      *
      * @exception Exception if an MBean cannot be created or registered
      */
-    public String createUserDatabaseRealm(String parent, String resourceName)
-        throws Exception {
+    public String createUserDatabaseRealm(String parent, String resourceName) throws Exception {
 
-         // Create a new UserDatabaseRealm instance
+        // Create a new UserDatabaseRealm instance
         UserDatabaseRealm realm = new UserDatabaseRealm();
         realm.setResourceName(resourceName);
 
@@ -617,26 +596,22 @@ public class MBeanFactory {
     /**
      * Create a new Valve and associate it with a {@link Container}.
      *
-     * @param className The fully qualified class name of the {@link Valve} to
-     *                  create
-     * @param parent    The MBean name of the associated parent
-     *                  {@link Container}.
+     * @param className The fully qualified class name of the {@link Valve} to create
+     * @param parent    The MBean name of the associated parent {@link Container}.
+     *
+     * @return The MBean name of the {@link Valve} that was created or <code>null</code> if the {@link Valve} does not
+     *             implement {@link JmxEnabled}.
      *
-     * @return  The MBean name of the {@link Valve} that was created or
-     *          <code>null</code> if the {@link Valve} does not implement
-     *          {@link JmxEnabled}.
      * @exception Exception if an MBean cannot be created or registered
      */
-    public String createValve(String className, String parent)
-            throws Exception {
+    public String createValve(String className, String parent) throws Exception {
 
         // Look for the parent
         ObjectName parentName = new ObjectName(parent);
         Container container = getParentContainerFromParent(parentName);
 
         if (container == null) {
-            // TODO
-            throw new IllegalArgumentException();
+            throw new IllegalArgumentException(sm.getString("mBeanFactory.noParent", parent));
         }
 
         Valve valve = (Valve) Class.forName(className).getConstructor().newInstance();
@@ -655,12 +630,12 @@ public class MBeanFactory {
      * Create a new Web Application Loader.
      *
      * @param parent MBean Name of the associated parent component
+     *
      * @return the object name of the created loader
      *
      * @exception Exception if an MBean cannot be created or registered
      */
-    public String createWebappLoader(String parent)
-        throws Exception {
+    public String createWebappLoader(String parent) throws Exception {
 
         // Create a new WebappLoader instance
         WebappLoader loader = new WebappLoader();
@@ -671,11 +646,7 @@ public class MBeanFactory {
         if (container instanceof Context) {
             ((Context) container).setLoader(loader);
         }
-        // FIXME add Loader.getObjectName
-        //ObjectName oname = loader.getObjectName();
-        ObjectName oname =
-            MBeanUtils.createObjectName(pname.getDomain(), loader);
-        return oname.toString();
+        return loader.getObjectName().toString();
 
     }
 
@@ -698,7 +669,7 @@ public class MBeanFactory {
             address = ObjectName.unquote(address);
         }
 
-        Connector conns[] = service.findConnectors();
+        Connector[] conns = service.findConnectors();
 
         for (Connector conn : conns) {
             String connAddress = null;
@@ -716,8 +687,7 @@ public class MBeanFactory {
                     conn.destroy();
                     break;
                 }
-            }
-            else if (address.equals(connAddress) && port.equals(connPort)) {
+            } else if (address.equals(connAddress) && port.equals(connPort)) {
                 service.removeConnector(conn);
                 conn.destroy();
                 break;
@@ -744,24 +714,20 @@ public class MBeanFactory {
         String name = oname.getKeyProperty("name");
         name = name.substring(2);
         int i = name.indexOf('/');
-        String hostName = name.substring(0,i);
+        String hostName = name.substring(0, i);
         String path = name.substring(i);
-        ObjectName deployer = new ObjectName(domain+":type=Deployer,host="+
-                                             hostName);
+        ObjectName deployer = new ObjectName(domain + ":type=Deployer,host=" + hostName);
         String pathStr = getPathStr(path);
-        if(mserver.isRegistered(deployer)) {
-            Boolean result = (Boolean) mserver.invoke(deployer,"tryAddServiced",
-                       new Object[]{pathStr},
-                       new String[] {"java.lang.String"});
+        if (mserver.isRegistered(deployer)) {
+            Boolean result = (Boolean) mserver.invoke(deployer, "tryAddServiced", new Object[] { pathStr },
+                    new String[] { "java.lang.String" });
             if (result.booleanValue()) {
                 try {
-                    mserver.invoke(deployer,"unmanageApp",
-                            new Object[] {pathStr},
-                            new String[] {"java.lang.String"});
+                    mserver.invoke(deployer, "unmanageApp", new Object[] { pathStr },
+                            new String[] { "java.lang.String" });
                 } finally {
-                    mserver.invoke(deployer,"removeServiced",
-                            new Object[] {pathStr},
-                            new String[] {"java.lang.String"});
+                    mserver.invoke(deployer, "removeServiced", new Object[] { pathStr },
+                            new String[] { "java.lang.String" });
                 }
             } else {
                 throw new IllegalStateException(sm.getString("mBeanFactory.removeContext.addServicedFail", pathStr));
@@ -772,12 +738,12 @@ public class MBeanFactory {
             Context context = (Context) host.findChild(pathStr);
             // Remove this component from its parent component
             host.removeChild(context);
-            if(context instanceof StandardContext) {
+            if (context instanceof StandardContext) {
                 try {
                     context.destroy();
                 } catch (Exception e) {
                     log.warn(sm.getString("mBeanFactory.contextDestroyError"), e);
-         }
+                }
             }
 
         }
@@ -801,7 +767,7 @@ public class MBeanFactory {
         Host host = (Host) engine.findChild(hostName);
 
         // Remove this component from its parent component
-        if(host!=null) {
+        if (host != null) {
             engine.removeChild(host);
         }
     }
@@ -869,7 +835,7 @@ public class MBeanFactory {
     public void removeService(String name) throws Exception {
 
         if (!(container instanceof Server)) {
-            throw new Exception();
+            throw new Exception(sm.getString("mBeanFactory.notServer"));
         }
 
         // Acquire a reference to the component to be removed
