@@ -29,8 +29,6 @@ import org.apache.tomcat.util.res.StringManager;
 
 /**
  * Identity input filter.
- *
- * @author Remy Maucherat
  */
 public class IdentityInputFilter implements InputFilter, ApplicationBufferHandler {
 
@@ -46,8 +44,7 @@ public class IdentityInputFilter implements InputFilter, ApplicationBufferHandle
     // ----------------------------------------------------- Static Initializer
 
     static {
-        ENCODING.setBytes(ENCODING_NAME.getBytes(StandardCharsets.ISO_8859_1),
-                0, ENCODING_NAME.length());
+        ENCODING.setBytes(ENCODING_NAME.getBytes(StandardCharsets.ISO_8859_1), 0, ENCODING_NAME.length());
     }
 
 
@@ -90,7 +87,7 @@ public class IdentityInputFilter implements InputFilter, ApplicationBufferHandle
     @Override
     public int doRead(ApplicationBufferHandler handler) throws IOException {
 
-        int result = -1;
+        int result;
 
         if (contentLength >= 0) {
             if (remaining > 0) {
@@ -115,6 +112,8 @@ public class IdentityInputFilter implements InputFilter, ApplicationBufferHandle
                 }
                 result = -1;
             }
+        } else {
+            result = -1;
         }
 
         return result;
@@ -126,8 +125,7 @@ public class IdentityInputFilter implements InputFilter, ApplicationBufferHandle
 
 
     /**
-     * {@inheritDoc}
-     * Read the content length from the request.
+     * {@inheritDoc} Read the content length from the request.
      */
     @Override
     public void setRequest(Request request) {
@@ -147,7 +145,7 @@ public class IdentityInputFilter implements InputFilter, ApplicationBufferHandle
 
             int nread = buffer.doRead(this);
             tempRead = null;
-            if (nread > 0 ) {
+            if (nread > 0) {
                 swallowed += nread;
                 remaining = remaining - nread;
                 if (maxSwallowSizeExceeded && swallowed > maxSwallowSize) {
