@@ -65,8 +65,6 @@ import org.apache.tomcat.util.net.jsse.JSSESupport;
 
 /**
  * NIO endpoint.
- *
- * @author Mladen Turk
  */
 public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel> {
 
@@ -660,7 +658,7 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
         }
 
         public int getKeyCount() {
-            return keyCount;
+            return selector.keys().size();
         }
 
         public Selector getSelector() {
@@ -736,8 +734,8 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                 } else if (interestOps == OP_REGISTER) {
                     try {
                         sc.register(getSelector(), SelectionKey.OP_READ, socketWrapper);
-                    } catch (Exception x) {
-                        log.error(sm.getString("endpoint.nio.registerFail"), x);
+                    } catch (Exception e) {
+                        log.error(sm.getString("endpoint.nio.registerFail"), e);
                     }
                 } else {
                     final SelectionKey key = sc.keyFor(getSelector());
@@ -983,6 +981,7 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                     try {
                         sd.fchannel.close();
                     } catch (Exception ignore) {
+                        // Ignore
                     }
                     // For calls from outside the Poller, the caller is
                     // responsible for registering the socket for the
@@ -1026,9 +1025,9 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                     }
                     return SendfileState.PENDING;
                 }
-            } catch (IOException e) {
+            } catch (IOException ioe) {
                 if (log.isDebugEnabled()) {
-                    log.debug(sm.getString("endpoint.sendfile.error"), e);
+                    log.debug(sm.getString("endpoint.sendfile.error"), ioe);
                 }
                 if (!calledByProcessor && sc != null) {
                     poller.cancelledKey(sk, socketWrapper);
@@ -1308,10 +1307,10 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                         getSocket().free();
                     }
                 }
-            } catch (Throwable e) {
-                ExceptionUtils.handleThrowable(e);
+            } catch (Throwable t) {
+                ExceptionUtils.handleThrowable(t);
                 if (log.isDebugEnabled()) {
-                    log.error(sm.getString("endpoint.debug.channelCloseFail"), e);
+                    log.error(sm.getString("endpoint.debug.channelCloseFail"), t);
                 }
             } finally {
                 socketBufferHandler = SocketBufferHandler.EMPTY;
@@ -1323,10 +1322,10 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                 if (data != null && data.fchannel != null && data.fchannel.isOpen()) {
                     data.fchannel.close();
                 }
-            } catch (Throwable e) {
-                ExceptionUtils.handleThrowable(e);
+            } catch (Throwable t) {
+                ExceptionUtils.handleThrowable(t);
                 if (log.isDebugEnabled()) {
-                    log.error(sm.getString("endpoint.sendfile.closeError"), e);
+                    log.error(sm.getString("endpoint.sendfile.closeError"), t);
                 }
             }
         }
@@ -1373,8 +1372,11 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                                 } else {
                                     readLock.wait();
                                 }
-                            } catch (InterruptedException e) {
-                                // Continue
+                            } catch (InterruptedException ignore) {
+                                /*
+                                 * Most likely the Poller signalling there is data to read but could be spurious. Exit
+                                 * the wait, check status and proceed accordingly.
+                                 */
                             }
                         }
                     }
@@ -1480,8 +1482,11 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                                 } else {
                                     writeLock.wait();
                                 }
-                            } catch (InterruptedException e) {
-                                // Continue
+                            } catch (InterruptedException ignore) {
+                                /*
+                                 * Most likely the Poller signalling that data can be written but could be spurious.
+                                 * Exit the wait, check status and proceed accordingly.
+                                 */
                             }
                         } else if (startNanos > 0) {
                             // If something was written, reset timeout
@@ -1731,8 +1736,8 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                                 completionDone = false;
                             }
                         }
-                    } catch (IOException e) {
-                        setError(e);
+                    } catch (IOException ioe) {
+                        setError(ioe);
                     }
                 }
                 if (nBytes > 0 || (nBytes == 0 && !buffersArrayHasRemaining(buffers, offset, length) &&
@@ -1808,11 +1813,11 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                         // the handshake completes.
                         event = SocketEvent.OPEN_READ;
                     }
-                } catch (IOException x) {
+                } catch (IOException ioe) {
                     handshake = -1;
                     if (logHandshake.isDebugEnabled()) {
                         logHandshake.debug(sm.getString("endpoint.err.handshake", socketWrapper.getRemoteAddr(),
-                                Integer.toString(socketWrapper.getRemotePort())), x);
+                                Integer.toString(socketWrapper.getRemotePort())), ioe);
                     }
                 } catch (CancelledKeyException ckx) {
                     handshake = -1;
