@@ -46,16 +46,13 @@ import org.apache.tomcat.util.compat.JreCompat;
 import org.apache.tomcat.util.res.StringManager;
 
 /**
- * The default {@link JarScanner} implementation scans the WEB-INF/lib directory
- * followed by the provided classloader and then works up the classloader
- * hierarchy. This implementation is sufficient to meet the requirements of the
- * Servlet 3.0 specification as well as to provide a number of Tomcat specific
- * extensions. The extensions are:
+ * The default {@link JarScanner} implementation scans the WEB-INF/lib directory followed by the provided classloader
+ * and then works up the classloader hierarchy. This implementation is sufficient to meet the requirements of the
+ * Servlet 3.0 specification as well as to provide a number of Tomcat specific extensions. The extensions are:
  * <ul>
- *   <li>Scanning the classloader hierarchy (enabled by default)</li>
- *   <li>Testing all files to see if they are JARs (disabled by default)</li>
- *   <li>Testing all directories to see if they are exploded JARs
- *       (disabled by default)</li>
+ * <li>Scanning the classloader hierarchy (enabled by default)</li>
+ * <li>Testing all files to see if they are JARs (disabled by default)</li>
+ * <li>Testing all directories to see if they are exploded JARs (disabled by default)</li>
  * </ul>
  * All of the extensions may be controlled via configuration.
  */
@@ -86,9 +83,11 @@ public class StandardJarScanner implements JarScanner {
      * Controls the classpath scanning extension.
      */
     private boolean scanClassPath = true;
+
     public boolean isScanClassPath() {
         return scanClassPath;
     }
+
     public void setScanClassPath(boolean scanClassPath) {
         this.scanClassPath = scanClassPath;
     }
@@ -97,9 +96,11 @@ public class StandardJarScanner implements JarScanner {
      * Controls the JAR file Manifest scanning extension.
      */
     private boolean scanManifest = true;
+
     public boolean isScanManifest() {
         return scanManifest;
     }
+
     public void setScanManifest(boolean scanManifest) {
         this.scanManifest = scanManifest;
     }
@@ -108,33 +109,38 @@ public class StandardJarScanner implements JarScanner {
      * Controls the testing all files to see of they are JAR files extension.
      */
     private boolean scanAllFiles = false;
+
     public boolean isScanAllFiles() {
         return scanAllFiles;
     }
+
     public void setScanAllFiles(boolean scanAllFiles) {
         this.scanAllFiles = scanAllFiles;
     }
 
     /**
-     * Controls the testing all directories to see of they are exploded JAR
-     * files extension.
+     * Controls the testing all directories to see of they are exploded JAR files extension.
      */
     private boolean scanAllDirectories = true;
+
     public boolean isScanAllDirectories() {
         return scanAllDirectories;
     }
+
     public void setScanAllDirectories(boolean scanAllDirectories) {
         this.scanAllDirectories = scanAllDirectories;
     }
 
     /**
-     * Controls the testing of the bootstrap classpath which consists of the
-     * runtime classes provided by the JVM and any installed system extensions.
+     * Controls the testing of the bootstrap classpath which consists of the runtime classes provided by the JVM and any
+     * installed system extensions.
      */
     private boolean scanBootstrapClassPath = false;
+
     public boolean isScanBootstrapClassPath() {
         return scanBootstrapClassPath;
     }
+
     public void setScanBootstrapClassPath(boolean scanBootstrapClassPath) {
         this.scanBootstrapClassPath = scanBootstrapClassPath;
     }
@@ -143,38 +149,35 @@ public class StandardJarScanner implements JarScanner {
      * Controls the filtering of the results from the scan for JARs
      */
     private JarScanFilter jarScanFilter = new StandardJarScanFilter();
+
     @Override
     public JarScanFilter getJarScanFilter() {
         return jarScanFilter;
     }
+
     @Override
     public void setJarScanFilter(JarScanFilter jarScanFilter) {
         this.jarScanFilter = jarScanFilter;
     }
 
     /**
-     * Scan the provided ServletContext and class loader for JAR files. Each JAR
-     * file found will be passed to the callback handler to be processed.
+     * Scan the provided ServletContext and class loader for JAR files. Each JAR file found will be passed to the
+     * callback handler to be processed.
      *
-     * @param scanType      The type of JAR scan to perform. This is passed to
-     *                          the filter which uses it to determine how to
-     *                          filter the results
-     * @param context       The ServletContext - used to locate and access
-     *                      WEB-INF/lib
-     * @param callback      The handler to process any JARs found
+     * @param scanType The type of JAR scan to perform. This is passed to the filter which uses it to determine how to
+     *                     filter the results
+     * @param context  The ServletContext - used to locate and access WEB-INF/lib
+     * @param callback The handler to process any JARs found
      */
     @Override
-    public void scan(JarScanType scanType, ServletContext context,
-            JarScannerCallback callback) {
+    public void scan(JarScanType scanType, ServletContext context, JarScannerCallback callback) {
 
         if (log.isTraceEnabled()) {
             log.trace(sm.getString("jarScan.webinflibStart"));
         }
 
-        if (jarScanFilter instanceof StandardJarScanFilter) {
-            if (((StandardJarScanFilter) jarScanFilter).isSkipAll()) {
-                return;
-            }
+        if (jarScanFilter.isSkipAll()) {
+            return;
         }
 
         Set<URL> processedURLs = new HashSet<>();
@@ -184,8 +187,7 @@ public class StandardJarScanner implements JarScanner {
         if (dirList != null) {
             for (String path : dirList) {
                 if (path.endsWith(Constants.JAR_EXT) &&
-                        getJarScanFilter().check(scanType,
-                                path.substring(path.lastIndexOf('/')+1))) {
+                        getJarScanFilter().check(scanType, path.substring(path.lastIndexOf('/') + 1))) {
                     // Need to scan this JAR
                     if (log.isDebugEnabled()) {
                         log.debug(sm.getString("jarScan.webinflibJarScan", path));
@@ -193,10 +195,14 @@ public class StandardJarScanner implements JarScanner {
                     URL url = null;
                     try {
                         url = context.getResource(path);
-                        processedURLs.add(url);
-                        process(scanType, callback, url, path, true, null);
-                    } catch (IOException e) {
-                        log.warn(sm.getString("jarScan.webinflibFail", url), e);
+                        if (url != null) {
+                            processedURLs.add(url);
+                            process(scanType, callback, url, path, true, null);
+                        } else {
+                            log.warn(sm.getString("jarScan.webinflibFail", path));
+                        }
+                    } catch (IOException ioe) {
+                        log.warn(sm.getString("jarScan.webinflibFail", url), ioe);
                     }
                 } else {
                     if (log.isTraceEnabled()) {
@@ -220,8 +226,8 @@ public class StandardJarScanner implements JarScanner {
                     if (url != null) {
                         try {
                             callback.scanWebInfClasses();
-                        } catch (IOException e) {
-                            log.warn(sm.getString("jarScan.webinfclassesFail"), e);
+                        } catch (IOException ioe) {
+                            log.warn(sm.getString("jarScan.webinfclassesFail"), ioe);
                         }
                     }
                 }
@@ -237,8 +243,8 @@ public class StandardJarScanner implements JarScanner {
     }
 
 
-    protected void doScanClassPath(JarScanType scanType, ServletContext context,
-            JarScannerCallback callback, Set<URL> processedURLs) {
+    protected void doScanClassPath(JarScanType scanType, ServletContext context, JarScannerCallback callback,
+            Set<URL> processedURLs) {
         if (log.isTraceEnabled()) {
             log.trace(sm.getString("jarScan.classloaderStart"));
         }
@@ -266,8 +272,7 @@ public class StandardJarScanner implements JarScanner {
                     isWebapp = isWebappClassLoader(classLoader);
                 }
 
-                classPathUrlsToProcess.addAll(
-                        Arrays.asList(((URLClassLoader) classLoader).getURLs()));
+                classPathUrlsToProcess.addAll(Arrays.asList(((URLClassLoader) classLoader).getURLs()));
 
                 processURLs(scanType, callback, processedURLs, isWebapp, classPathUrlsToProcess);
             }
@@ -286,13 +291,11 @@ public class StandardJarScanner implements JarScanner {
     }
 
 
-    protected void processURLs(JarScanType scanType, JarScannerCallback callback,
-            Set<URL> processedURLs, boolean isWebapp, Deque<URL> classPathUrlsToProcess) {
+    protected void processURLs(JarScanType scanType, JarScannerCallback callback, Set<URL> processedURLs,
+            boolean isWebapp, Deque<URL> classPathUrlsToProcess) {
 
-        if (jarScanFilter instanceof StandardJarScanFilter) {
-            if (((StandardJarScanFilter) jarScanFilter).isSkipAll()) {
-                return;
-            }
+        if (jarScanFilter.isSkipAll()) {
+            return;
         }
 
         while (!classPathUrlsToProcess.isEmpty()) {
@@ -309,11 +312,8 @@ public class StandardJarScanner implements JarScanner {
             // Directories are scanned for pluggability scans or
             // if scanAllDirectories is enabled unless the
             // filter says not to.
-            if ((cpe.isJar() ||
-                    scanType == JarScanType.PLUGGABILITY ||
-                    isScanAllDirectories()) &&
-                            getJarScanFilter().check(scanType,
-                                    cpe.getName())) {
+            if ((cpe.isJar() || scanType == JarScanType.PLUGGABILITY || isScanAllDirectories()) &&
+                    getJarScanFilter().check(scanType, cpe.getName())) {
                 if (log.isDebugEnabled()) {
                     log.debug(sm.getString("jarScan.classloaderJarScan", url));
                 }
@@ -336,7 +336,7 @@ public class StandardJarScanner implements JarScanner {
     protected void addClassPath(Deque<URL> classPathUrlsToProcess) {
         String classPath = System.getProperty("java.class.path");
 
-        if (classPath == null || classPath.length() == 0) {
+        if (classPath == null || classPath.isEmpty()) {
             return;
         }
 
@@ -353,18 +353,14 @@ public class StandardJarScanner implements JarScanner {
 
 
     /*
-     * Since class loader hierarchies can get complicated, this method attempts
-     * to apply the following rule: A class loader is a web application class
-     * loader unless it loaded this class (StandardJarScanner) or is a parent
-     * of the class loader that loaded this class.
+     * Since class loader hierarchies can get complicated, this method attempts to apply the following rule: A class
+     * loader is a web application class loader unless it loaded this class (StandardJarScanner) or is a parent of the
+     * class loader that loaded this class.
      *
-     * This should mean:
-     *   the webapp class loader is an application class loader
-     *   the shared class loader is an application class loader
-     *   the server class loader is not an application class loader
-     *   the common class loader is not an application class loader
-     *   the system class loader is not an application class loader
-     *   the bootstrap class loader is not an application class loader
+     * This should mean: the webapp class loader is an application class loader the shared class loader is an
+     * application class loader the server class loader is not an application class loader the common class loader is
+     * not an application class loader the system class loader is not an application class loader the bootstrap class
+     * loader is not an application class loader
      */
     private static boolean isWebappClassLoader(ClassLoader classLoader) {
         return !CLASSLOADER_HIERARCHY.contains(classLoader);
@@ -372,12 +368,10 @@ public class StandardJarScanner implements JarScanner {
 
 
     /*
-     * Scan a URL for JARs with the optional extensions to look at all files
-     * and all directories.
+     * Scan a URL for JARs with the optional extensions to look at all files and all directories.
      */
-    protected void process(JarScanType scanType, JarScannerCallback callback,
-            URL url, String webappPath, boolean isWebapp, Deque<URL> classPathUrlsToProcess)
-            throws IOException {
+    protected void process(JarScanType scanType, JarScannerCallback callback, URL url, String webappPath,
+            boolean isWebapp, Deque<URL> classPathUrlsToProcess) throws IOException {
 
         if (log.isTraceEnabled()) {
             log.trace(sm.getString("jarScan.jarUrlStart", url));
@@ -422,8 +416,7 @@ public class StandardJarScanner implements JarScanner {
     }
 
 
-    private void processManifest(Jar jar, boolean isWebapp,
-            Deque<URL> classPathUrlsToProcess) throws IOException {
+    private void processManifest(Jar jar, boolean isWebapp, Deque<URL> classPathUrlsToProcess) throws IOException {
 
         // Not processed for web application JARs nor if the caller did not
         // provide a Deque of URLs to append to.
@@ -441,7 +434,7 @@ public class StandardJarScanner implements JarScanner {
             String[] classPathEntries = classPathAttribute.split(" ");
             for (String classPathEntry : classPathEntries) {
                 classPathEntry = classPathEntry.trim();
-                if (classPathEntry.length() == 0) {
+                if (classPathEntry.isEmpty()) {
                     continue;
                 }
                 URL jarURL = jar.getJarFileURL();
@@ -449,14 +442,11 @@ public class StandardJarScanner implements JarScanner {
                 try {
                     URI jarURI = jarURL.toURI();
                     /*
-                     * Note: Resolving the relative URLs from the manifest has the
-                     *       potential to introduce security concerns. However, since
-                     *       only JARs provided by the container and NOT those provided
-                     *       by web applications are processed, there should be no
-                     *       issues.
-                     *       If this feature is ever extended to include JARs provided
-                     *       by web applications, checks should be added to ensure that
-                     *       any relative URL does not step outside the web application.
+                     * Note: Resolving the relative URLs from the manifest has the potential to introduce security
+                     * concerns. However, since only JARs provided by the container and NOT those provided by web
+                     * applications are processed, there should be no issues. If this feature is ever extended to
+                     * include JARs provided by web applications, checks should be added to ensure that any relative URL
+                     * does not step outside the web application.
                      */
                     URI classPathEntryURI = jarURI.resolve(classPathEntry);
                     classPathEntryURL = classPathEntryURI.toURL();
@@ -477,7 +467,7 @@ public class StandardJarScanner implements JarScanner {
         private final boolean jar;
         private final String name;
 
-        public ClassPathEntry(URL url) {
+        ClassPathEntry(URL url) {
             String path = url.getPath();
             int end = path.lastIndexOf(Constants.JAR_EXT);
             if (end != -1) {
