@@ -61,6 +61,7 @@ import org.apache.coyote.http2.Http2Parser.Input;
 import org.apache.coyote.http2.Http2Parser.Output;
 import org.apache.tomcat.util.compat.JrePlatform;
 import org.apache.tomcat.util.http.FastHttpDateFormat;
+import org.apache.tomcat.util.http.Method;
 import org.apache.tomcat.util.http.MimeHeaders;
 import org.apache.tomcat.util.http.parser.Priority;
 import org.apache.tomcat.util.net.TesterSupport;
@@ -222,7 +223,7 @@ public abstract class Http2TestBase extends TomcatBaseTest {
     protected void buildGetRequest(byte[] frameHeader, ByteBuffer headersPayload, byte[] padding, int streamId,
             String url) {
         List<Header> headers = new ArrayList<>(4);
-        headers.add(new Header(":method", "GET"));
+        headers.add(new Header(":method", Method.GET));
         headers.add(new Header(":scheme", "http"));
         headers.add(new Header(":path", url));
         headers.add(new Header(":authority", "localhost:" + getPort()));
@@ -260,7 +261,7 @@ public abstract class Http2TestBase extends TomcatBaseTest {
 
     protected void buildSimpleGetRequestPart1(byte[] frameHeader, ByteBuffer headersPayload, int streamId) {
         List<Header> headers = new ArrayList<>(3);
-        headers.add(new Header(":method", "GET"));
+        headers.add(new Header(":method", Method.GET));
         headers.add(new Header(":scheme", "http"));
         headers.add(new Header(":path", "/simple"));
 
@@ -373,7 +374,7 @@ public abstract class Http2TestBase extends TomcatBaseTest {
             byte[] padding, boolean withTrailers, int streamId) {
 
         MimeHeaders headers = new MimeHeaders();
-        headers.addValue(":method").setString("POST");
+        headers.addValue(":method").setString(Method.POST);
         headers.addValue(":scheme").setString("http");
         headers.addValue(":path").setString(path);
         headers.addValue(":authority").setString("localhost:" + getPort());
@@ -449,7 +450,7 @@ public abstract class Http2TestBase extends TomcatBaseTest {
 
     protected void buildHeadRequest(byte[] headersFrameHeader, ByteBuffer headersPayload, int streamId, String path) {
         MimeHeaders headers = new MimeHeaders();
-        headers.addValue(":method").setString("HEAD");
+        headers.addValue(":method").setString(Method.HEAD);
         headers.addValue(":scheme").setString("http");
         headers.addValue(":path").setString(path);
         headers.addValue(":authority").setString("localhost:" + getPort());
@@ -668,6 +669,11 @@ public abstract class Http2TestBase extends TomcatBaseTest {
     }
 
     protected void openClientConnection(boolean tls) throws IOException {
+        openClientConnection(tls, true);
+    }
+
+    protected void openClientConnection(boolean tls, boolean autoAckSettings) throws IOException {
+
         SocketFactory socketFactory = tls ? TesterSupport.configureClientSsl() : SocketFactory.getDefault();
         // Open a connection
         s = socketFactory.createSocket("localhost", getPort());
@@ -677,7 +683,7 @@ public abstract class Http2TestBase extends TomcatBaseTest {
         InputStream is = s.getInputStream();
 
         input = new TestInput(is);
-        output = new TestOutput();
+        output = new TestOutput(autoAckSettings);
         parser = new TesterHttp2Parser("-1", input, output);
         hpackEncoder = new HpackEncoder();
     }
@@ -799,7 +805,7 @@ public abstract class Http2TestBase extends TomcatBaseTest {
     }
 
 
-    void sendClientPreface() throws IOException {
+    protected void sendClientPreface() throws IOException {
         os.write(Http2Parser.CLIENT_PREFACE_START);
         os.write(EMPTY_SETTINGS_FRAME);
         os.flush();
@@ -1062,6 +1068,8 @@ public abstract class Http2TestBase extends TomcatBaseTest {
 
     public class TestOutput implements Output, HeaderEmitter {
 
+        private final boolean autoAckSettings;
+
         private StringBuffer trace = new StringBuffer();
         private String lastStreamId = "0";
         private ConnectionSettingsRemote remoteSettings = new ConnectionSettingsRemote("-1");
@@ -1070,6 +1078,10 @@ public abstract class Http2TestBase extends TomcatBaseTest {
         private long bytesRead;
         private volatile HpackDecoder hpackDecoder = null;
 
+        public TestOutput(boolean autoAckSettings) {
+            this.autoAckSettings = autoAckSettings;
+        }
+
         public void setTraceBody(boolean traceBody) {
             this.traceBody = traceBody;
         }
@@ -1089,14 +1101,14 @@ public abstract class Http2TestBase extends TomcatBaseTest {
 
 
         @Override
-        public ByteBuffer startRequestBodyFrame(int streamId, int payloadSize, boolean endOfStream) {
+        public ByteBuffer startRequestBodyFrame(int streamId, int dataLength, boolean endOfStream) {
             lastStreamId = Integer.toString(streamId);
-            bytesRead += payloadSize;
+            bytesRead += dataLength;
             if (traceBody) {
-                bodyBuffer = ByteBuffer.allocate(payloadSize);
+                bodyBuffer = ByteBuffer.allocate(dataLength);
                 return bodyBuffer;
             } else {
-                trace.append(lastStreamId + "-Body-" + payloadSize + "\n");
+                trace.append(lastStreamId + "-Body-" + dataLength + "\n");
                 return null;
             }
         }
@@ -1200,7 +1212,9 @@ public abstract class Http2TestBase extends TomcatBaseTest {
                 trace.append("0-Settings-Ack\n");
             } else {
                 trace.append("0-Settings-End\n");
-                sendSettings(0, true);
+                if (autoAckSettings) {
+                    sendSettings(0, true);
+                }
             }
         }
 
